@@ -2,28 +2,21 @@
 
 use strict;
 
-use Getopt::Std;
 use File::Which;
 use File::Basename;
+use Getopt::Std;
 use HTML::Template;
-use Tk;
+use Pod::Usage;
 
 use CVS::Metrics;
 
+use Tk;
+
 my %opts;
 getopts('f:hst:vDHS:', \%opts);
 
 if ($opts{h}) {
-	print "Usage: $0 [-h] [-f file.log] [-s] [-t title] [-D] [-H] [-S \"yyyy/mm/dd\"]\n";
-	print "\t-h : help\n";
-	print "\t-f file.log : off-line mode\n";
-	print "\t-s : use an extern style sheet\n";
-	print "\t-t title\n";
-	print "\t-v : version\n";
-	print "\t-D : suppress 'dead' files in tree\n";
-	print "\t-H : append HEAD as a tag\n";
-	print "\t-S start_date : yyyy/mm/dd \n";
-	exit(0);
+	pod2usage(-verbose => 1);
 }
 
 if ($opts{v}) {
@@ -79,22 +72,22 @@ if ($opts{S}) {
 
 cvs_tklog - Extract from cvs log
 
-=head1 SYNOPSYS
+=head1 SYNOPSIS
 
-cvs_tklog [B<-h>] [B<-f> I<file.log>] [B<-t> I<title>] [B<-s>] [B<-D>] [B<-H>] [B<-S> I<yyyy/mm/dd>]
+cvs_tklog [B<-f> I<file.log>] [B<-t> I<title>] [B<-s>] [B<-D>] [B<-H>] [B<-S> I<yyyy/mm/dd>]
 
 =head1 OPTIONS
 
 =over 8
 
-=item -h
-
-Display Usage.
-
 =item -f
 
 Mode off-line.
 
+=item -h
+
+Display Usage.
+
 =item -s
 
 use an extern style sheet (cvs_tklog.css).
@@ -103,6 +96,10 @@ use an extern style sheet (cvs_tklog.css).
 
 Specify the main title.
 
+=item -v
+
+Display Version.
+
 =item -D
 
 suppress 'dead' files in tree.
@@ -148,11 +145,17 @@ in the current directory. The file could contains the following variables :
 
  $flg_dead = 1;		# or 0
 
- $start_date = "2002/01/01";
+ $start_date = "2003/01/01";
 
 =head1 SEE ALSO
 
-cvs_activity, cvs_energy
+cvs_activity, cvs_energy, cvs_wxlog, cvs_current
+
+=head1 COPYRIGHT
+
+(c) 2003-2004 Francois PERRAD, France. All rights reserved.
+
+This library is distributed under the terms of the Artistic Licence.
 
 =head1 AUTHOR
 
@@ -194,9 +197,9 @@ sub FindCvs {
 	my $cvs = which('cvs');
 
 	if ( !defined $cvs and $^O eq 'MSWin32' ) {
-		use Win32::TieRegistry(Delimiter => "/");
-
-		my $cvs_setting = $Registry->{"HKEY_CURRENT_USER/Software/WinCvs/wincvs/CVS settings"};
+		my $cvs_setting;
+		eval 'use Win32::TieRegistry(Delimiter => "/")';
+		eval '$cvs_setting = $Registry->{"HKEY_CURRENT_USER/Software/WinCvs/wincvs/CVS settings"}';
 		$cvs = $cvs_setting->{'/P_WhichCvs'};
 		if (defined $cvs) {
 			$cvs =~ s/[\000\001]//g;
@@ -351,11 +354,13 @@ my $style = q{
 
 	my $e_img = "e_${title_full}.png";
 	$e_img =~ s/\//_/g;
-	open OUT, "> $e_img"
-			or die "can't open $e_img ($!).\n";
-	binmode OUT, ":raw";
-	print OUT $image->png();
-	close OUT;
+	if (defined $image) {
+		open OUT, "> $e_img"
+				or die "can't open $e_img ($!).\n";
+		binmode OUT, ":raw";
+		print OUT $image->png();
+		close OUT;
+	}
 
 	my $timed_tag = $cvs_log->getTimedTag();
 	my @timed_tag = ();
@@ -379,11 +384,13 @@ my $style = q{
 
 	my $a_img = "a_${title_full}.png";
 	$a_img =~ s/\//_/g;
-	open OUT, "> $a_img"
-			or die "can't open $a_img ($!).\n";
-	binmode OUT, ":raw";
-	print OUT $image->png();
-	close OUT;
+	if (defined $image) {
+		open OUT, "> $a_img"
+				or die "can't open $a_img ($!).\n";
+		binmode OUT, ":raw";
+		print OUT $image->png();
+		close OUT;
+	}
 
 	my $dir_evol = $cvs_log->getDirEvolution($path, $tag_from, $tag_to);
 	my @summary = ();
@@ -682,16 +689,5 @@ sub _audit {
 	my $html = main::GenerateHTML($self->{cvs_log}, $self->{tags}, $self->{title}, $path, $self->{tag_from}, $self->{tag_to}, $self->{css}, $self->{start_date});
 	print "Starting browser...\n";
 	system "start $html";
-#	use POSIX qw(getcwd);
-#	my $uri = "file://" . POSIX::getcwd() . "/" . $html;
-#	system "start $uri";
-#	system "cmd /s \"C:/Program Files/Internet Explorer/iexplore.exe\" $uri";
-#	system "\"C:/Program Files/Netscape/Communicator/Program/netscape.exe\" file://$html";
-
-#	use WIN32::OLE;
-#	my $ie = Win32::OLE->new('IExplore.Application') or warn "oops\n";
 }
 
-
-
-
